@@ -33,7 +33,9 @@ setMethod("print", signature(x = "dfm"),
                       format(nfeat(x), big.mark=","), " feature",
                       if (nfeat(x) > 1L || nfeat(x) == 0L) "s" else "",
                       if (is.resampled(x)) paste0(", ", nresample(x), " resamples") else "",
-                      if (prod(dim(x))) paste0(" (", format(sparsity(x)*100, digits = 3), "% sparse)"),
+                      if (prod(dim(x))) format_sparsity(sparsity(x)),
+                          # paste0(" (", format(sparsity(x)*100, digits = 3), "% sparse)"),
+                          # paste0(" (", format(sparsity(x)*100, digits = 6, nsmall = 2, scientific = 4), "% sparse)"),
                       ".\n", sep = "")
               }
               print_dfm(x, ndoc, nfeat, show.values, show.settings, ...)
@@ -43,6 +45,51 @@ setMethod("print", signature(x = "dfm"),
 #' @param object the item to be printed
 setMethod("show", signature(object = "dfm"), function(object) print(object))
 
+
+#' format a sparsity value for printing
+#'
+#' Inputs a dfm sparsity value from \code{\link{sparsity}} and formats it for
+#' printing in \code{\link{print.dfm}}.
+#' @param x input sparsity value, ranging from 0 to 1.0
+#' @param threshold value below which the decimal places will be rounded and
+#'   printed with an inequality
+#' @param digits \code{digits} input to \code{\link{format}}
+#' @param nsmall \code{nsmall} input to \code{\link{format}}
+#' @return \code{character} value for inserting into the dfm print ouput
+#' @examples 
+#' s <- c(.9, .99, .999, .9999, .99999, 
+#'        .1, .01, .001, .0001, .000001, .0000001, .00000001, .000000000001, 
+#'        sparsity(dfm(data_corpus_inaugural)),
+#'        sparsity(dfm(data_corpus_irishbudget2010)),
+#'        .12312431242134)
+#' for (i in s) 
+#'     print(paste0(format(i, width = 10),  ":  ", quanteda:::format_sparsity(i)))
+#' print(as.dfm(Matrix::rsparsematrix(1000, 1000, density = 0.9999)))
+#' print(as.dfm(Matrix::rsparsematrix(10000, 10000, density = 0.00001)))
+#' @keywords internal
+format_sparsity <- function(x, threshold = .01, digits = 3, nsmall = 1) {
+    if (x < 0 || x > 1.0)
+        stop("illegal sparsity value; must be 0 <= x <= 1.0")
+    sep = ""
+    threshold_char <- as.character(threshold)
+    sparsity100 <- x * 100
+    
+    # for edge cases
+    if ((sparsity100 == threshold || sparsity100 == (100 - threshold)) && digits <= 3) 
+        digits <- 4
+        
+    sparsity_output <- if (sparsity100 < threshold && sparsity100 > 0.00) {
+        paste("<", stringi::stri_trim_left(as.character(format(threshold, digits = 4, nsmall = 2))), sep = sep)
+    } else if (sparsity100 > (100 - threshold) && sparsity100 < 100.00) {
+        paste(">", stringi::stri_trim_left(as.character(format(100 - threshold, digits = 4, nsmall = 2))), sep = sep)
+    } else {
+        stringi::stri_trim_left(format(sparsity100, digits = digits, nsmall = nsmall))
+    }
+    
+    paste(" (", sparsity_output, "% sparse)", sep = "")
+}
+
+
 # internal function for print.dfm and print.fcm
 print_dfm <- function(x, ndoc, nfeat, show_values, show_settings, ...) {
     
