@@ -1,10 +1,12 @@
 #' Calculate lexical diversity
 #' 
 #' Calculate the lexical diversity or complexity of text(s).
-#' @details \code{textstat_lexdiv} calculates a variety of proposed indices for lexical
-#'   diversity. In the following formulae, \eqn{N} refers to the total number of
-#'   tokens, and \eqn{V} to the number of types: \describe{
-#'   
+#' @details \code{textstat_lexdiv} calculates a variety of proposed indices for
+#'   lexical diversity. In the following formulas, \eqn{N} refers to the total
+#'   number of tokens, \eqn{V} to the number of types, and \eqn{f_v(i, N)} to the
+#'   numbers of types occurring \eqn{i} times in a sample of length \eqn{N}.
+#'   \describe{
+#'      
 #'   \item{\code{"TTR"}:}{The ordinary \emph{Type-Token Ratio}: \deqn{TTR =
 #'   \frac{V}{N}}{TTR =  V / N}}
 #'   
@@ -25,12 +27,18 @@
 #'   \item{\code{"S"}:}{Summer's index: \deqn{S = 
 #'   \frac{\log{\log{V}}}{\log{\log{N}}}}{S = log(log(V)) / log(log(N))}}
 #'   
-#'   \item{\code{"K"}:}{Yule's \emph{K}  (Yule, 1944, as cited in Tweedie &
-#'   Baayen, 1998) is calculated by: \deqn{K = 10^4 \times
-#'   \frac{(\sum_{X=1}^{X}{{f_X}X^2}) - N}{N^2}}{K = 10^4 * (sum(fX*X^2) - N) /
-#'   N^2} where \eqn{N} is the number of tokens, \eqn{X} is a vector with the
-#'   frequencies of each type, and \eqn{f_X}{fX} is the frequencies for each X.}
+#'   \item{\code{"K"}:}{Yule's \emph{K}  (Yule, 1944, as presented in Tweedie &
+#'   Baayen, 1998, Eq. 16) is calculated by: \deqn{K = 10^4 \times
+#'   \left[ -\frac{1}{N} + \sum_{i=1}^{V} f_v(i, N) \left( \frac{i}{N} \right)^2 \right] }}
 #'   
+#'   \item{\code{"D"}:}{Simpson's \emph{D}  (Simpson 1949, as presented in
+#'   Tweedie & Baayen, 1998, Eq. 17) is calculated by:
+#'   \deqn{D = \sum_{i=1}^{V} f_v(i, N) \frac{i}{N} \frac{i-1}{N-1}}}
+#'
+#'   \item{\code{"Vm"}:}{Herdan's \eqn{V_m}  (Herdan 1955, as presented in
+#'   Tweedie & Baayen, 1998, Eq. 18) is calculated by:
+#'   \deqn{V_m = \sqrt{ \sum_{i=1}^{V} f_v(i, N) (i/N)^2 - \frac{i}{V} }}}
+#'
 #'   \item{\code{"Maas"}:}{Maas' indices (\eqn{a}, \eqn{\log{V_0}} & 
 #'   \eqn{\log{}_{e}{V_0}}): \deqn{a^2 = \frac{\log{N} -
 #'   \log{V}}{\log{N}^2}}{a^2 = log(N) - log(V) / log(N)^2} \deqn{\log{V_0} =
@@ -47,8 +55,7 @@
 #'   
 #'   }
 #'   
-#' @param x an input object, such as a \link[=dfm]{document-feature matrix}
-#'   object
+#' @param x an input \link{dfm}
 #' @param measure a character vector defining the measure to calculate.
 #' @param log.base a numeric value defining the base of the logarithm (for
 #'   measures using logs)
@@ -62,27 +69,35 @@
 #'   Diversity) proposed by McCarthy & Jarvis (2010) or Jarvis (no year), or the
 #'   HD-D version of vocd-D (see McCarthy & Jarvis, 2007).  These are available
 #'   from the package \pkg{korRpus}.
-#' @references Covington, M.A. & McFall, J.D. (2010). Cutting the Gordian Knot: 
-#'   The Moving-Average Type-Token Ratio (MATTR). \emph{Journal of Quantitative 
-#'   Linguistics}, 17(2), 94--100.
+#' @references 
+#'   Covington, M.A. & McFall, J.D. (2010). "Cutting the Gordian Knot: 
+#'   The Moving-Average Type-Token Ratio (MATTR)". \emph{Journal of Quantitative 
+#'   Linguistics} 17(2), 94--100.
 #'   
-#'   Maas, H.-D., (1972). \"Uber den Zusammenhang zwischen Wortschatzumfang und 
-#'   L\"ange eines Textes. \emph{Zeitschrift f\"ur Literaturwissenschaft und 
-#'   Linguistik}, 2(8), 73--96.
+#'   Herdan, Gustav. 1955. "A New Derivation and Interpretation of Yule's
+#'   'Characteristic' \emph{K}." \emph{Zeitschrift für angewandte Mathematik und
+#'   Physik} 6(4): 332--34.
 #'   
-#'   McCarthy, P.M. & Jarvis, S. (2007). vocd: A theoretical and empirical 
-#'   evaluation. \emph{Language Testing}, 24(4), 459--488.
+#'   Maas, H.-D., (1972). "\"Uber den Zusammenhang zwischen Wortschatzumfang und 
+#'   L\"ange eines Textes". \emph{Zeitschrift f\"ur Literaturwissenschaft und 
+#'   Linguistik} 2(8), 73--96.
 #'   
-#'   McCarthy, P.M. & Jarvis, S. (2010). MTLD, vocd-D, and HD-D: A validation 
-#'   study of sophisticated approaches to lexical diversity assessment. 
-#'   \emph{Behaviour Research Methods}, 42(2), 381--392.
+#'   McCarthy, P.M. & Jarvis, S. (2007). "vocd: A theoretical and empirical 
+#'   evaluation". \emph{Language Testing} 24(4), 459--488.
+#'   
+#'   McCarthy, P.M. & Jarvis, S. (2010). "MTLD, vocd-D, and HD-D: A validation 
+#'   study of sophisticated approaches to lexical diversity assessment". 
+#'   \emph{Behaviour Research Methods} 42(2), 381--392.
 #'   
 #'   Michalke, Meik.  (2014) \emph{koRpus: An R Package for Text Analysis}. 
 #'   Version 0.05-5. \url{http://reaktanz.de/?c=hacking&s=koRpus}
 #'   
-#'   Tweedie. F.J. & Baayen, R.H. (1998). How Variable May a Constant Be? 
-#'   Measures of Lexical Richness in Perspective. \emph{Computers and the 
-#'   Humanities}, 32(5), 323--352.
+#'   Simpson, Edward H. 1949. "Measurement of Diversity." \emph{Nature} 163: 688.
+#'   
+#'   Tweedie. F.J. & Baayen, R.H. (1998). "How Variable May a Constant Be? 
+#'   Measures of Lexical Richness in Perspective". \emph{Computers and the 
+#'   Humanities} 32(5), 323--352.
+#'   
 #' @return \code{textstat_lexdiv} returns a data.frame of documents and
 #'   their lexical diversity scores.
 #' @export
@@ -91,26 +106,26 @@
 #' (result <- textstat_lexdiv(mydfm, c("CTTR", "TTR", "U")))
 #' cor(textstat_lexdiv(mydfm, "all")[,-1])
 #' 
-textstat_lexdiv <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "U", "S", "Maas"), 
+textstat_lexdiv <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "U", "S", "K", "D", "Vm", "Maas"), 
                             log.base = 10) {
     UseMethod("textstat_lexdiv")
 }
 
 
 #' @export
-textstat_lexdiv.default <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "U", "S", "Maas"), 
+textstat_lexdiv.default <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "U", "S", "K", "D", "Vm", "Maas"), 
                                 log.base = 10) {
     stop(friendly_class_undefined_message(class(x), "textstat_lexdiv"))
 }
 
 #' @export
-textstat_lexdiv.dfm <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "U", "S", "Maas"), 
+textstat_lexdiv.dfm <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "U", "S", "K", "D", "Vm", "Maas"), 
                                 log.base = 10) {
     
     x <- as.dfm(x)
     if (!sum(x)) stop(message_error("dfm_empty"))
     
-    measure_option <- c("TTR", "C", "R", "CTTR", "U", "S", "Maas")
+    measure_option <- c("TTR", "C", "R", "CTTR", "U", "S", "K", "D", "Vm", "Maas")
     if (measure[1] == 'all') {
         measure <- measure_option
     } else {
@@ -119,7 +134,7 @@ textstat_lexdiv.dfm <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "
             stop("Invalid measure(s): ", measure[!is_valid])
     }
     
-    n_tokens <- n_types <- TTR <- C <- R <- CTTR <- U <- S <- Maas <- lgV0 <- lgeV0 <- NULL
+    n_tokens <- n_types <- TTR <- C <- R <- CTTR <- U <- S <- Maas <- lgV0 <- lgeV0 <- K <- D <- Vm <- NULL
     temp <- data.table(n_tokens = ntoken(x), n_types = ntype(x))
                                
     if ("TTR" %in% measure)
@@ -142,6 +157,32 @@ textstat_lexdiv.dfm <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "
         temp[, S := log(log(n_types, base = log.base), base = log.base) / 
                        log(log(n_tokens, base = log.base), base = log.base)]
     
+    # computations for K, D, Vm
+    # produces a list of data.frames that will be used for computing the measures
+    if (length(intersect(c("K", "D", "Vm"), measure))) {
+        ViN <- lapply(docnames(x), function(y) {
+            result <- as.data.frame(table(colSums(x[y, ])), stringsAsFactors = FALSE)
+            names(result) <- c("i", "ViN")
+            result[["i"]] <- as.integer(result[["i"]])
+            result[["n_tokens"]] <- ntoken(x)[y]
+            result[["n_types"]] <- ntype(x)[y]
+            subset(result, result$i > 0)
+        })
+    }
+        
+    if ("K" %in% measure)
+        temp[, K := 10^4 * vapply(ViN, function(y) sum(y$ViN * (y$i / y$n_tokens)^2), numeric(1))]
+    
+    if ("D" %in% measure)
+        temp[, D := vapply(ViN, 
+                           function(y) sum(y$ViN * (y$i / y$n_tokens) * ((y$i - 1) / (y$n_tokens - 1))), 
+                           numeric(1))]
+        
+    if ("Vm" %in% measure) 
+        temp[, Vm := vapply(ViN, 
+                            function(y) sqrt( sum(y$ViN * (y$i / y$n_tokens)^2) - 1 / y$n_types[1] ),
+                            numeric(1))]
+        
     if ("Maas" %in% measure) {
         measure <- c(measure, "lgV0", "lgeV0")
         temp[, Maas := sqrt((log(n_tokens, base = log.base) - log(n_types, base = log.base)) / 
@@ -151,7 +192,7 @@ textstat_lexdiv.dfm <- function(x, measure = c("all", "TTR", "C", "R", "CTTR", "
     }
     result <- data.frame(document = docnames(x), stringsAsFactors = FALSE)
     result <- cbind(result, as.data.frame(temp[,measure, with = FALSE]))
-    class(result) <- c('lexdiv', 'textstat', 'data.frame')
+    class(result) <- c("lexdiv", "textstat", "data.frame")
     rownames(result) <- as.character(seq_len(nrow(result)))
     return(result)
 }
