@@ -5,88 +5,88 @@
 #' @param x a character, \link{corpus}, or \link{tokens} object to be tokenized
 #' @keywords tokens
 #' @export
-#' @param what the unit for splitting the text, available alternatives are: 
-#'   \describe{ \item{\code{"word"}}{(recommended default) smartest, but 
-#'   slowest, word tokenization method; see 
-#'   \link[stringi]{stringi-search-boundaries} for details.} 
-#'   \item{\code{"fasterword"}}{dumber, but faster, word tokenization method, 
-#'   uses \code{{\link[stringi]{stri_split_charclass}(x, "\\\\p{WHITE_SPACE}")}}} 
-#'   \item{\code{"fastestword"}}{dumbest, but fastest, word tokenization method,
-#'   calls \code{\link[stringi]{stri_split_fixed}(x, " ")}} 
-#'   \item{\code{"character"}}{tokenization into individual characters} 
-#'   \item{\code{"sentence"}}{sentence segmenter, smart enough to handle some 
-#'   exceptions in English such as "Prof. Plum killed Mrs. Peacock." (but far 
+#' @param what the unit for splitting the text, available alternatives are:
+#'   \describe{ \item{\code{"word"}}{(recommended default) smartest, but
+#'   slowest, word tokenization method; see
+#'   \link[stringi]{stringi-search-boundaries} for details.}
+#'   \item{\code{"fasterword"}}{dumber, but faster, word tokenization method,
+#'   uses \code{\link[stringi]{stri_split_charclass}(x,
+#'   "[\\\\p{Z}\\\\p{C}]+")}} \item{\code{"fastestword"}}{dumbest, but fastest,
+#'   word tokenization method, calls \code{\link[stringi]{stri_split_fixed}(x, "
+#'   ")}} \item{\code{"character"}}{tokenization into individual characters}
+#'   \item{\code{"sentence"}}{sentence segmenter, smart enough to handle some
+#'   exceptions in English such as "Prof. Plum killed Mrs. Peacock." (but far
 #'   from perfect).} }
-#' @param remove_numbers remove tokens that consist only of numbers, but not 
+#' @param remove_numbers remove tokens that consist only of numbers, but not
 #'   words that start with digits, e.g. \code{2day}
-#' @param remove_punct if \code{TRUE}, remove all characters in the Unicode 
+#' @param remove_punct if \code{TRUE}, remove all characters in the Unicode
 #'   "Punctuation" [P] class
-#' @param remove_symbols if \code{TRUE}, remove all characters in the Unicode 
+#' @param remove_symbols if \code{TRUE}, remove all characters in the Unicode
 #'   "Symbol" [S] class
-#' @param remove_twitter remove Twitter characters \code{@@} and \code{#}; set to
-#'   \code{TRUE} if you wish to eliminate these.  Note that this will always be set 
-#'   to \code{FALSE} if \code{remove_punct = FALSE}.
-#' @param remove_url if \code{TRUE}, find and eliminate URLs beginning with 
+#' @param remove_twitter remove Twitter characters \code{@@} and \code{#}; set
+#'   to \code{TRUE} if you wish to eliminate these.  Note that this will always
+#'   be set to \code{FALSE} if \code{remove_punct = FALSE}.
+#' @param remove_url if \code{TRUE}, find and eliminate URLs beginning with
 #'   http(s) -- see section "Dealing with URLs".
-#' @param remove_hyphens if \code{TRUE}, split words that are connected by 
-#'   hyphenation and hyphenation-like characters in between words, e.g. 
-#'   \code{"self-storage"} becomes \code{c("self", "storage")}.  Default is 
-#'   \code{FALSE} to preserve such words as is, with the hyphens.  Only applies 
-#'   if \code{what = "word"}.
-#' @param remove_separators remove separators and separator characters (spaces 
-#'   and variations of spaces, plus tab, newlines, and anything else in the 
-#'   Unicode "separator" category) when \code{remove_punct=FALSE}.  Only 
-#'   applicable for \code{what = "character"} (when you probably want it to be 
+#' @param remove_hyphens if \code{TRUE}, split words that are connected by
+#'   hyphenation and hyphenation-like characters in between words, e.g.
+#'   \code{"self-storage"} becomes \code{c("self", "storage")}.  Default is
+#'   \code{FALSE} to preserve such words as is, with the hyphens.  Only applies
+#'   if \code{what = "word"} or \code{what = "fasterword"}.
+#' @param remove_separators if \code{TRUE}, remove separators and separator
+#'   characters (Unicode "Separator" [Z] and "Control [C]" categories). Only
+#'   applicable for \code{what = "character"} (when you probably want it to be
 #'   \code{FALSE}) and for \code{what = "word"} (when you probably want it to be
-#'   \code{TRUE}).  Note that if \code{what = "word"} and  
-#'   \code{remove_punct = TRUE}, then \code{remove_separators} has no effect.  Use
-#'   carefully.
-#' @param ngrams integer vector of the \emph{n} for \emph{n}-grams, defaulting 
-#'   to \code{1} (unigrams). For bigrams, for instance, use \code{2}; for 
-#'   bigrams and unigrams, use \code{1:2}.  You can even include irregular 
-#'   sequences such as \code{2:3} for bigrams and trigrams only.  See 
+#'   \code{TRUE}).
+#' @param ngrams integer vector of the \emph{n} for \emph{n}-grams, defaulting
+#'   to \code{1} (unigrams). For bigrams, for instance, use \code{2}; for
+#'   bigrams and unigrams, use \code{1:2}.  You can even include irregular
+#'   sequences such as \code{2:3} for bigrams and trigrams only.  See
 #'   \code{\link{tokens_ngrams}}.
-#' @param skip integer vector specifying the skips for skip-grams, default is 0 
-#'   for only immediately neighbouring words. Only applies if \code{ngrams} is 
+#' @param skip integer vector specifying the skips for skip-grams, default is 0
+#'   for only immediately neighbouring words. Only applies if \code{ngrams} is
 #'   different from the default of 1.  See \code{\link{tokens_skipgrams}}.
 #' @param concatenator character to use in concatenating \emph{n}-grams, default
-#'   is "\code{_}", which is recommended since this is included in the regular 
+#'   is "\code{_}", which is recommended since this is included in the regular
 #'   expression and Unicode definitions of "word" characters
-#' @param verbose if \code{TRUE}, print timing messages to the console; off by 
+#' @param verbose if \code{TRUE}, print timing messages to the console; off by
 #'   default
-#' @param include_docvars if \code{TRUE}, pass docvars and metadoc fields through to 
-#'   the tokens object.  Only applies when tokenizing \link{corpus} objects.
+#' @param include_docvars if \code{TRUE}, pass docvars and metadoc fields
+#'   through to the tokens object.  Only applies when tokenizing \link{corpus}
+#'   objects.
 #' @param ... additional arguments not used
 #' @import stringi
-#' @details The tokenizer is designed to be fast and flexible as well as to 
+#' @details The tokenizer is designed to be fast and flexible as well as to
 #'   handle Unicode correctly. Most of the time, users will construct \link{dfm}
-#'   objects from texts or a corpus, without calling \code{tokens()} as an 
+#'   objects from texts or a corpus, without calling \code{tokens()} as an
 #'   intermediate step.  Since \code{tokens()} is most likely to be used by more
-#'   technical users, we have set its options to default to minimal 
-#'   intervention. This means that punctuation is tokenized as well, and that 
-#'   nothing is removed by default from the text being tokenized except 
+#'   technical users, we have set its options to default to minimal
+#'   intervention. This means that punctuation is tokenized as well, and that
+#'   nothing is removed by default from the text being tokenized except
 #'   inter-word spacing and equivalent characters.
-#'   
-#'   Note that a \code{tokens} constructor also works on \link{tokens} objects, 
-#'   which allows setting additional options that will modify the original object.
-#'   It is not possible, however, to change a setting to "un-remove" something 
-#'   that was removed from the input \link{tokens} object, however.  For instance,
-#'   \code{tokens(tokens("Ha!", remove_punct = TRUE), remove_punct = FALSE)} will 
-#'   not restore the \code{"!"} token.  No warning is currently issued about this,
-#'   so the user should use \code{tokens.tokens()} with caution.
-#'  
+#'
+#'   Note that a \code{tokens} constructor also works on \link{tokens} objects,
+#'   which allows setting additional options that will modify the original
+#'   object. It is not possible, however, to change a setting to "un-remove"
+#'   something that was removed from the input \link{tokens} object, however.
+#'   For instance, \code{tokens(tokens("Ha!", remove_punct = TRUE), remove_punct
+#'   = FALSE)} will not restore the \code{"!"} token.  No warning is currently
+#'   issued about this, so the user should use \code{tokens.tokens()} with
+#'   caution.
+#'
 #' @section Dealing with URLs: URLs are tricky to tokenize, because they contain
-#'   a number of symbols and punctuation characters.  If you wish to remove 
-#'   these, as most people do, and your text contains URLs, then you should set 
-#'   \code{what = "fasterword"} and \code{remove_url = TRUE}.  If you wish to 
-#'   keep the URLs, but do not want them mangled, then your options are more 
-#'   limited, since removing punctuation and symbols will also remove them from 
+#'   a number of symbols and punctuation characters.  If you wish to remove
+#'   these, as most people do, and your text contains URLs, then you should set
+#'   \code{what = "fasterword"} and \code{remove_url = TRUE}.  If you wish to
+#'   keep the URLs, but do not want them mangled, then your options are more
+#'   limited, since removing punctuation and symbols will also remove them from
 #'   URLs.  We are working on improving this behaviour.
-#'   
+#'
 #'   See the examples below.
-#' @return \pkg{quanteda} \code{tokens} class object, by default a serialized list 
-#'   of integers corresponding to a vector of types.
-#' @seealso \code{\link{tokens_ngrams}}, \code{\link{tokens_skipgrams}}, \code{\link{as.list.tokens}}
+#' @return \pkg{quanteda} \code{tokens} class object, by default a serialized
+#'   list of integers corresponding to a vector of types.
+#' @seealso \code{\link{tokens_ngrams}}, \code{\link{tokens_skipgrams}},
+#'   \code{\link{as.list.tokens}}
 #' @keywords tokens
 #' @examples
 #' txt <- c(doc1 = "This is a sample: of tokens.",
@@ -102,23 +102,23 @@
 #' tokens("<tags> and other + symbols.", remove_symbols = TRUE)
 #' tokens("<tags> and other + symbols.", remove_symbols = FALSE, what = "fasterword")
 #' tokens("<tags> and other + symbols.", remove_symbols = TRUE, what = "fasterword")
-#' 
+#'
 #' ## examples with URLs - hardly perfect!
 #' txt <- "Repo https://githib.com/kbenoit/quanteda, and www.stackoverflow.com."
 #' tokens(txt, remove_url = TRUE, remove_punct = TRUE)
 #' tokens(txt, remove_url = FALSE, remove_punct = TRUE)
 #' tokens(txt, remove_url = FALSE, remove_punct = TRUE, what = "fasterword")
 #' tokens(txt, remove_url = FALSE, remove_punct = FALSE, what = "fasterword")
-#' 
-#' 
+#'
+#'
 #' ## MORE COMPARISONS
 #' txt <- "#textanalysis is MY <3 4U @@myhandle gr8 #stuff :-)"
 #' tokens(txt, remove_punct = TRUE)
 #' tokens(txt, remove_punct = TRUE, remove_twitter = TRUE)
 #' #tokens("great website http://textasdata.com", remove_url = FALSE)
 #' #tokens("great website http://textasdata.com", remove_url = TRUE)
-#' 
-#' txt <- c(text1="This is $10 in 999 different ways,\n up and down; left and right!", 
+#'
+#' txt <- c(text1="This is $10 in 999 different ways,\n up and down; left and right!",
 #'          text2="@@kenbenoit working: on #quanteda 2day\t4ever, http://textasdata.com?page=123.")
 #' tokens(txt, verbose = TRUE)
 #' tokens(txt, remove_numbers = TRUE, remove_punct = TRUE)
@@ -127,27 +127,27 @@
 #' tokens(txt, remove_numbers = FALSE, remove_punct = FALSE)
 #' tokens(txt, remove_numbers = FALSE, remove_punct = FALSE, remove_separators = FALSE)
 #' tokens(txt, remove_numbers = TRUE, remove_punct = TRUE, remove_url = TRUE)
-#' 
+#'
 #' # character level
 #' tokens("Great website: http://textasdata.com?page=123.", what = "character")
-#' tokens("Great website: http://textasdata.com?page=123.", what = "character", 
+#' tokens("Great website: http://textasdata.com?page=123.", what = "character",
 #'          remove_separators = FALSE)
-#' 
-#' # sentence level         
-#' tokens(c("Kurt Vongeut said; only assholes use semi-colons.", 
-#'            "Today is Thursday in Canberra:  It is yesterday in London.", 
+#'
+#' # sentence level
+#' tokens(c("Kurt Vongeut said; only assholes use semi-colons.",
+#'            "Today is Thursday in Canberra:  It is yesterday in London.",
 #'            "Today is Thursday in Canberra:  \nIt is yesterday in London.",
-#'            "To be?  Or\nnot to be?"), 
+#'            "To be?  Or\nnot to be?"),
 #'           what = "sentence")
 #' tokens(data_corpus_inaugural[c(2,40)], what = "sentence")
-#' 
+#'
 #' # removing features (stopwords) from tokenized texts
 #' txt <- char_tolower(c(mytext1 = "This is a short test sentence.",
 #'                       mytext2 = "Short.",
 #'                       mytext3 = "Short, shorter, and shortest."))
 #' tokens(txt, remove_punct = TRUE)
 #' tokens_remove(tokens(txt, remove_punct = TRUE), stopwords("english"))
-#' 
+#'
 #' # ngram tokenization
 #' tokens(txt, remove_punct = TRUE, ngrams = 2)
 #' tokens(txt, remove_punct = TRUE, ngrams = 2, skip = 1, concatenator = " ")
@@ -567,8 +567,9 @@ tokens_internal <- function(x, what = c("word", "sentence", "character", "fastes
                 " not used.", sep = "", call. = FALSE, noBreaks. = TRUE)
     }
     
-    # deprecate "simplify"
-    if ("simplify" %in% names(added_args)) warning("simplify no longer available")
+    if (!remove_separators && what %in% c("fasterword", "fastestword"))
+        warning("remove_separators = FALSE has no effect when what = fasterword or fastestword",
+                call. = FALSE, noBreaks. = TRUE)
     
     if (!is.integer(ngrams)) ngrams <- as.integer(ngrams)
     
@@ -664,10 +665,10 @@ tokens_word <- function(txt,
                         remove_separators = TRUE,
                         verbose = FALSE){
     
-    if (what=="fastestword") {
+    if (what == "fastestword") {
         tok <- stri_split_fixed(txt, " ")
-    } else if (what=="fasterword") {
-        tok <- stri_split_regex(txt, "\\p{Z}+")
+    } else if (what == "fasterword") {
+        tok <- stri_split_regex(txt, "[\\p{Z}\\p{C}]+") 
     } else {
         txt <- stri_replace_all_regex(txt, "[\uFE00-\uFE0F]", '') # remove variant selector
         txt <- stri_replace_all_regex(txt, "\\s[\u0300-\u036F]", '') # remove whitespace with diacritical marks
@@ -722,7 +723,7 @@ tokens_sentence <- function(txt, verbose = FALSE){
         x <- stri_trim_right(x) # trim trailing spaces
         x <- stri_replace_all_fixed(x, "_pd_", ".") # replace the non-full-stop "." characters
         return(x)
-    } )
+    })
     
     return(tok)
 }
@@ -768,10 +769,10 @@ tokens_character <- function(txt,
 #' This function recompiles a serialized tokens object when the vocabulary has
 #' been changed in a way that makes some of its types identical, such as
 #' lowercasing when a lowercased version of the type already exists in the type
-#' table, or introduces gaps in the integer map of the types.  It also reindexes
-#' the types attribute to account for types that may have become duplicates,
-#' through a procedure such as stemming or lowercasing; or the addition of new
-#' tokens through compounding.
+#' table, or introduces gaps in the integer map of the types.  It also
+#' re-indexes the types attribute to account for types that may have become
+#' duplicates, through a procedure such as stemming or lowercasing; or the
+#' addition of new tokens through compounding.
 #' @param x the \link{tokens} object to be recompiled
 #' @param gap if \code{TRUE}, remove gaps between token IDs
 #' @param dup if \code{TRUE}, merge duplicated token types into the same ID 
