@@ -9,15 +9,19 @@ using namespace quanteda;
 * @creator Kohei Watanabe
 * @param texts_ tokens ojbect
 * @param types_ types in tokens
+* @param gap if TRUE, remove gaps between token IDs
+* @param dup if TRUE, merge duplicated token types into the same ID 
 */
 
 // [[Rcpp::export]]
 List qatd_cpp_tokens_recompile(const List &texts_, 
-                               const CharacterVector types_){
+                               const CharacterVector types_,
+                               const bool gap = true,
+                               const bool dup = true){
     
     Texts texts = Rcpp::as<Texts>(texts_);
     Types types = Rcpp::as<Types>(types_);
-    return recompile(texts, types);
+    return recompile(texts, types, gap, dup);
     
 }
 
@@ -25,7 +29,7 @@ List qatd_cpp_tokens_recompile(const List &texts_,
 
 #toks3 <- list(rep(0:5, 1), rep(10:15, 1))
 toks3 <- list(0:26)
-qatd_cpp_tokens_recompile(toks4, letters)
+qatd_cpp_tokens_recompile(toks3, letters)
 
 toks4 <- list(c(1:5))
 qatd_cpp_tokens_recompile(toks4, c('あ', 'い', 'う', 'え', 'お'))
