@@ -1,6 +1,6 @@
 context('test plots.R')
 
-dev.new(width = 10, height = 10)
+pdf(file = tempfile(".pdf"), width = 10, height = 10)
 
 test_that("test plot.kwic scale argument default", {
 
@@ -116,7 +116,7 @@ test_that("test textplot_wordcloud comparison works", {
     testdfm <- dfm(testcorp, remove = stopwords("english"))
     testdfm_grouped <- dfm(testcorp, remove = stopwords("english"), groups = "label")
     
-    dev.new(width = 10, height = 10)
+    jpeg(filename = tempfile(".jpg"), width = 5000, height = 5000)
     expect_silent(
         textplot_wordcloud(testdfm_grouped, comparison = TRUE)
     )
@@ -134,13 +134,15 @@ test_that("test textplot_wordcloud comparison works", {
 })
 
 test_that("test textplot_wordcloud raise deprecation message", {
-    
+    jpeg(filename = tempfile(".jpg"), width = 5000, height = 5000)  
     mt <- dfm(data_corpus_inaugural[1:5])
     mt <- dfm_trim(mt, min_termfreq = 10)
     expect_warning(textplot_wordcloud(mt, min.freq = 10), 'min.freq is deprecated')
     expect_warning(textplot_wordcloud(mt, use.r.layout = 10), 'use.r.layout is no longer use')
+    dev.off()
 })
 
+
 test_that("test textplot_scale1d wordfish in the most basic way", {
     wf <- textmodel_wordfish(dfm(data_corpus_irishbudget2010), dir = c(6,5))
     expect_false(identical(textplot_scale1d(wf, sort = TRUE), 
@@ -161,7 +163,8 @@ test_that("test textplot_scale1d wordfish in the most basic way", {
 test_that("test textplot_scale1d wordscores in the most basic way", {
     mt <- dfm(data_corpus_irishbudget2010)
     ws <- textmodel_wordscores(mt, c(rep(NA, 4), -1, 1, rep(NA, 8)))
-    pr <- predict(ws, mt, force = TRUE)
+    pr <- suppressWarnings(predict(ws, mt, force = TRUE))
+    
     expect_false(identical(textplot_scale1d(pr, sort = TRUE), 
                            textplot_scale1d(pr, sort = FALSE)))
     expect_silent(textplot_scale1d(pr, sort = TRUE, groups = docvars(data_corpus_irishbudget2010, "party")))
@@ -181,7 +184,7 @@ test_that("test textplot_scale1d wordscores in the most basic way", {
         "This margin can only be run on a predicted wordscores object"
     )
     expect_error(
-        textplot_scale1d(predict(ws), margin = "features"),
+        suppressWarnings(textplot_scale1d(predict(ws), margin = "features")),
         "This margin can only be run on a fitted wordscores object"
     )
 })
@@ -227,20 +230,6 @@ test_that("test textplot_keyness: show_reference works correctly ", {
 
 })
 
-test_that("test textplot_network", {
-    txt <- "A D A C E A D F E B A C E D"
-    testfcm <- fcm(txt, context = "window", window = 3, tri = FALSE)
-    testdfm <- dfm(txt)
-    expect_silent(textplot_network(testfcm, vertex_color = 'red', offset = 0.1))
-    expect_silent(textplot_network(testdfm, offset = 0.1))
-    expect_error(textplot_network(testfcm, min_freq = 100), 
-                 'There is no co-occurence higher than the threshold')
-    
-    # works with interger color
-    expect_silent(textplot_network(testfcm, vertex_color = 2))
-    expect_silent(textplot_network(testfcm, edge_color = 2))
-})
-
 test_that("test textplot_affinity", {
     af <- textmodel_affinity(data_dfm_lbgexample, y = c("L", NA, NA, NA, "R", NA))
     afpred <- predict(af) 
@@ -248,33 +237,5 @@ test_that("test textplot_affinity", {
     expect_silent(textplot_influence(summary(influence(afpred))))
 })
 
-test_that("test textplot_network works with vectorlized argument", {
-    txt <- "A D A C E A D F E B A C E D"
-    
-    testfcm <- fcm(txt, context = "window", window = 3, tri = FALSE)
-    expect_silent(textplot_network(testfcm, vertex_color = rep(c(1, 2), nrow(testfcm) / 2)))
-    expect_silent(textplot_network(testfcm, vertex_size = rowSums(testfcm) / 5))
-    expect_silent(textplot_network(testfcm, vertex_labelcolor = rep(c(1, NA), nrow(testfcm) / 2)))
-})
-
-test_that("textplot_network error when fcm is too large", {
-    testdfm <- dfm(data_corpus_irishbudget2010)
-    expect_error(textplot_network(testdfm, min_freq = 1, offset = 0, omit_isolated = FALSE),
-                   'fcm is too large for a network plot')
-})
-
-test_that("test textplot_network font-selection", {
-    txt <- "A D A C E A D F E B A C E D"
-    testfcm <- fcm(txt, context = "window", window = 3, tri = FALSE)
-    testdfm <- dfm(txt)
-    expect_silent(textplot_network(testfcm, offset = 0.1, 
-                                   vertex_labelfont = "serif"))
-    expect_silent(textplot_network(testdfm, offset = 0.1, 
-                                   vertex_labelfont = "sans"))
-    expect_error(textplot_network(testfcm, min_freq = 0.1, 
-                                  vertex_labelfont = "not_a_real_font"),
-               "not_a_real_font is not found on your system")
-})
-
 dev.off()
 
